@@ -12,6 +12,10 @@
 
 #include <KPackage/Package>
 #include <KQuickAddons/ManagedConfigModule>
+#if HAVE_KUSERFEEDBACK
+#include <KUserFeedback/Provider>
+#endif
+
 #include <QJsonArray>
 #include <QJsonValue>
 
@@ -81,7 +85,7 @@ class KCMLandingPage : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(LookAndFeelGroup *defaultDarkLookAndFeel READ defaultDarkLookAndFeel CONSTANT)
 
 public:
-    KCMLandingPage(QObject *parent, const QVariantList &args);
+    KCMLandingPage(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~KCMLandingPage() override
     {
     }
@@ -117,8 +121,8 @@ private:
 
     MostUsedModel *m_mostUsedModel = nullptr;
 
-    QHash<int, QHash<QString, QJsonArray>> m_uses;
 #if HAVE_KUSERFEEDBACK
+    QHash<KUserFeedback::Provider::TelemetryMode, QHash<QString, QJsonArray>> m_uses;
     QJsonArray m_feedbackSources;
 #endif
     bool m_lnfDirty = false;
