@@ -20,7 +20,11 @@ Q_SIGNALS:
     void leave();
 
 protected:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEvent *) override;
+#else
+    void enterEvent(QEnterEvent *) override;
+#endif
     void leaveEvent(QEvent *) override;
 
 private:
